<?php

namespace Drupal\multisite_manager_tool\Controller;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\multisite_manager_tool\Form\CacheClearSiteForm;
use Drupal\multisite_manager_tool\Form\CacheClearSitesForm;
use Drupal\multisite_manager_tool\SitesHelper;

/**
 * Returns responses for Multisite manager tool routes.
 */
final class ManageCachesController implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Sites helper service.
   *
   * @var \Drupal\multisite_manager_tool\SitesHelper
   */
  protected $sitesHelper;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected FormBuilderInterface $formBuilder;

  public function __construct(
    SitesHelper $sites_helper,
    MessengerInterface $messenger,
    FormBuilderInterface $form_builder,
  ) {
    $this->sitesHelper = $sites_helper;
    $this->messenger = $messenger;
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('sites_helper'),
      $container->get('messenger'),
      $container->get("form_builder")
    );
  }

  /**
   * Displays the system multisite manager tool page.
   *
   * @return array
   *   A render array containing the multisite-manager-tool form.
   */
  public function build(): array {

    if (!$this->sitesHelper->checkIfOneSite()) {
      $this->messenger->addWarning(
        $this->t('Only one site is active, there is no multisite configuration. See the <a href=":url" target="_blank">Multisite Drupal</a> page for more information.',
        [':url' => 'https://www.drupal.org/docs/getting-started/multisite-drupal'])
          );
      return [];
    }

    return [
      'cache_clear_sites' => $this->formBuilder->getForm(CacheClearSitesForm::class),
      'cache_clear_site' => $this->formBuilder->getForm(CacheClearSiteForm::class),
    ];
  }

}
