<?php

namespace Drupal\multisite_manager_tool\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\multisite_manager_tool\SitesHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Cache clear by site form.
 */
final class CacheClearSiteForm extends FormBase {

  /**
   * Sites helper service.
   *
   * @var \Drupal\multisite_manager_tool\SitesHelper
   */
  protected $sitesHelper;

  public function __construct(SitesHelper $sites_helper) {
    $this->sitesHelper = $sites_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('sites_helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'multisite_manager_cache_clear_site_tool';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $sites = $this->sitesHelper->getMultisiteList();
    foreach ($sites as $site) {
      $rows[] = [
        'site' => $site,
      ];
    }

    $form['table'] = [
      '#type' => 'table',
      '#header' => [
        $this->t('Site'),
        $this->t('Actions'),
      ],
      '#rows' => [],
    ];

    foreach ($rows as $key => $row) {
      $form['table'][$key]['site'] = [
        '#plain_text' => $row['site'],
      ];
      $form['table'][$key]['actions'] = [
        '#type' => 'actions',
        'edit' => [
          '#type' => 'submit',
          '#value' => $this->t('Clear cache'),
          '#name' => "clear_{$row['site']}",
          '#limit_validation_errors' => [],
          '#attributes' => ['class' => ['button', 'button--primary']],
        ],
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $trigger = $form_state->getTriggeringElement();
    preg_match('/clear_(.+)/', $trigger['#name'], $matches);

    if (isset($matches[1])) {
      $site = $matches[1];
      $site_path = DRUPAL_ROOT . "/sites/$site";

      if (!is_dir($site_path)) {
        $this->messenger()->addError($this->t('Site: @site not found', ['@site' => $site]));
        return;
      }

      $this->sitesHelper->drushCommandSite($site, "cache:rebuild");
      $this->messenger()->addMessage($this->t('Caches cleared in: @site', ['@site' => $site]));
    }
  }

}
