<?php

namespace Drupal\multisite_manager_tool\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\multisite_manager_tool\SitesHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Cache clear all sites form.
 */
final class CacheClearSitesForm extends FormBase {

  /**
   * Sites helper service.
   *
   * @var \Drupal\multisite_manager_tool\SitesHelper
   */
  protected $sitesHelper;

  public function __construct(SitesHelper $sites_helper) {
    $this->sitesHelper = $sites_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('sites_helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'multisite_manager_cache_clear_sites_tool';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $form['clear_cache'] = [
      '#type' => 'submit',
      '#value' => $this->t('Clear caches all sites'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $sites = $this->sitesHelper->getMultisiteList();
    foreach ($sites as $site) {
      $site_path = DRUPAL_ROOT . "/sites/$site";

      if (!is_dir($site_path)) {
        continue;
      }

      $this->sitesHelper->drushCommandSite($site, "cache:rebuild");
    }
    $this->messenger()->addStatus($this->t('Caches cleared.'));
  }

}
